﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using BatchUpdatesWithEditTemplate.Models;
using Infragistics.Web.Mvc;

namespace BatchUpdatesWithEditTemplate.Controllers
{
    public class HomeController : Controller
    {
        //
        // GET: /Home/
        CustomersViewModel viewModel;
        public ActionResult Index()
        {
            //This object will serve as the basis for binding to data
            //on the Index.cshtml View with the MVC Helpers. See:
            //@model = BatchUpdatesWithEditTemplate.Models.CustomersViewModel
            viewModel = new CustomersViewModel
            {
                //IEnumerable of Customer Objects
                Customers = GetCustomers(),

                //IEnumerable of CustomerCountSummary Objects
                //For use with binding to the Chart
                CustomerCountSummaries = GetCustomerCounts()
            };

            return View(viewModel);
        }


        [ActionName("EditingSaveChanges")]
        public ActionResult EditingSaveChanges()
        {
            viewModel = new CustomersViewModel
            {
                //IEnumerable of Customer Objects
                Customers = GetCustomers(),

                //IEnumerable of CustomerCountSummary Objects
                //For use with binding to the Chart
                CustomerCountSummaries = GetCustomerCounts()
            };

            ViewData["GenerateCompactJSONResponse"] = false;
            GridModel m = new GridModel();
            List<Transaction<Customer>> transactions = m.LoadTransactions<Customer>(HttpContext.Request.Form["ig_transactions"]);

            foreach (Transaction<Customer> t in transactions)
            {
                if (t.type == "newrow")
                {
                    this.viewModel.Customers.ToList().Add(t.row);
                }
                else if (t.type == "deleterow")
                {
                    var customer = (from c in this.viewModel.Customers
                                   where c.ID == Int32.Parse(t.rowId)
                                   select c).Single();

                    this.viewModel.Customers.ToList().Remove(customer);
                }
                else if (t.type == "row")
                {
                    var customer = (from c in this.viewModel.Customers
                                   where c.ID == Int32.Parse(t.rowId)
                                   select c).Single();

                    if (t.row.Name != null)
                    {
                        customer.Name = t.row.Name;
                    }
                    if (t.row.IsActive != null)
                    {
                        customer.IsActive = t.row.IsActive;
                    }
                  
                }
            }

            JsonResult result = new JsonResult();
            Dictionary<string, bool> response = new Dictionary<string, bool>();
            response.Add("Success", true);
            result.Data = response;
            return result;
        }
    



        //This method aggregates the Customer data into a format that is easily
        //consumed by the Chart
        private IEnumerable<CustomerCountSummary> GetCustomerCounts()
        {
            var customers = GetCustomers();
            var active = from c in customers
                         where c.IsActive
                         select c;

            var inActive = from c in customers
                           where (c.IsActive == false)
                           select c;

            return new List<CustomerCountSummary> { 
                new CustomerCountSummary { CategoryLabel = "Active", CustomerCount = active.Count() },
                new CustomerCountSummary { CategoryLabel = "Inactive", CustomerCount = inActive.Count() }
            };
        }

        private IEnumerable<Customer> GetCustomers()
        {
            return new List<Customer>
            {
                new Customer { ID=1, Name="John Smith", IsActive=true },
                new Customer { ID=2, Name="Bob Richards", IsActive=false },
                new Customer { ID=3, Name="Marge Wright", IsActive=false },
                new Customer { ID=4, Name="Dwight Long", IsActive=true },
                new Customer { ID=5, Name="Amy Grant", IsActive=true },
            };
        }
    }
}